@@ -1,21 +1,9 @@
 /*
  *  birthdaydlg.cpp  -  dialog to pick birthdays from address book
  *  Program:  kalarm
- *  Copyright © 2002-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2002-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "birthdaydlg.h"
@@ -63,7 +51,22 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
     setObjectName(QStringLiteral("BirthdayDlg"));    // used by LikeBack
     setWindowTitle(i18nc("@title:window", "Import Birthdays From KAddressBook"));
 
-    QVBoxLayout* topLayout = new QVBoxLayout(this);
+    auto* topLayout = new QVBoxLayout(this);
+
+    if (Preferences::useAlarmName())
+    {
+        auto* hlayout = new QHBoxLayout();
+        hlayout->setContentsMargins(0, 0, 0, 0);
+        topLayout->addLayout(hlayout);
+        QLabel* label = new QLabel(i18nc("@label:textbox", "Alarm name:"), this);
+        label->setFixedSize(label->sizeHint());
+        hlayout->addWidget(label);
+        mName = new KLineEdit(this);
+        mName->setMinimumSize(mName->sizeHint());
+        label->setBuddy(mName);
+        mName->setWhatsThis(i18nc("@info:whatsthis", "Enter a name to help you identify this alarm. This is optional and need not be unique."));
+        hlayout->addWidget(mName);
+    }
 
     // Prefix and suffix to the name in the alarm text
     // Get default prefix and suffix texts from config file
@@ -73,7 +76,7 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
 
     QGroupBox* textGroup = new QGroupBox(i18nc("@title:group", "Alarm Text"), this);
     topLayout->addWidget(textGroup);
-    QGridLayout* grid = new QGridLayout(textGroup);
+    auto* grid = new QGridLayout(textGroup);
     QLabel* label = new QLabel(i18nc("@label:textbox", "Prefix:"), textGroup);
     label->setFixedSize(label->sizeHint());
     grid->addWidget(label, 0, 0);
@@ -100,7 +103,7 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
 
     QGroupBox* group = new QGroupBox(i18nc("@title:group", "Select Birthdays"), this);
     topLayout->addWidget(group);
-    QVBoxLayout* layout = new QVBoxLayout(group);
+    auto* layout = new QVBoxLayout(group);
     layout->setContentsMargins(0, 0, 0, 0);
 
     // Start Akonadi server as we need it for the birthday model to access contacts information
@@ -109,10 +112,10 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
     BirthdayModel* model = BirthdayModel::instance();
     connect(model, &BirthdayModel::dataChanged, this, &BirthdayDlg::resizeViewColumns);
 
-    KDescendantsProxyModel* descendantsModel = new KDescendantsProxyModel(this);
+    auto* descendantsModel = new KDescendantsProxyModel(this);
     descendantsModel->setSourceModel(model);
 
-    Akonadi::EntityMimeTypeFilterModel* mimeTypeFilter = new Akonadi::EntityMimeTypeFilterModel(this);
+    auto* mimeTypeFilter = new Akonadi::EntityMimeTypeFilterModel(this);
     mimeTypeFilter->setSourceModel(descendantsModel);
     mimeTypeFilter->addMimeTypeExclusionFilter(Akonadi::Collection::mimeType());
     mimeTypeFilter->setHeaderGroup(Akonadi::EntityTreeModel::ItemListHeaders);
@@ -143,10 +146,10 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
 
     group = new QGroupBox(i18nc("@title:group", "Alarm Configuration"), this);
     topLayout->addWidget(group);
-    QVBoxLayout* groupLayout = new QVBoxLayout(group);
+    auto* groupLayout = new QVBoxLayout(group);
 
     // Sound checkbox and file selector
-    QHBoxLayout* hlayout = new QHBoxLayout();
+    auto* hlayout = new QHBoxLayout();
     hlayout->setContentsMargins(0, 0, 0, 0);
     groupLayout->addLayout(hlayout);
     mSoundPicker = new SoundPicker(group);
@@ -241,8 +244,8 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
 
 
     KActionCollection* actions = new KActionCollection(this);
-    KStandardAction::selectAll(mListView, SLOT(selectAll()), actions);
-    KStandardAction::deselect(mListView, SLOT(clearSelection()), actions);
+    KStandardAction::selectAll(mListView, &QTreeView::selectAll, actions);
+    KStandardAction::deselect(mListView, &QTreeView::clearSelection, actions);
     actions->addAssociatedWidget(mListView);
     const auto lstActions = actions->actions();
     for (QAction* action : lstActions)
@@ -257,32 +260,34 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
 QVector<KAEvent> BirthdayDlg::events() const
 {
     QVector<KAEvent> list;
-    const QModelIndexList indexes = mListView->selectionModel()->selectedRows();
-    int count = indexes.count();
+    const QModelIndexList indexes = mListView->selectionModel()->selectedRows();     //clazy:exclude=inefficient-qlist
+    const int count = indexes.count();
     if (!count)
         return list;
+    list.reserve(count);
     const QDate today = KADateTime::currentLocalDate();
     const KADateTime todayStart(today, KADateTime::LocalZone);
-    int thisYear = today.year();
-    int reminder = mReminder->minutes();
-    for (int i = 0;  i < count;  ++i)
+    const int thisYear = today.year();
+    const int reminder = mReminder->minutes();
+    for (const QModelIndex& index : indexes)
     {
-        const QModelIndex nameIndex = indexes[i].model()->index(indexes[i].row(), 0);
-        const QModelIndex birthdayIndex = indexes[i].model()->index(indexes[i].row(), 1);
+        const QModelIndex nameIndex     = index.model()->index(index.row(), 0);
+        const QModelIndex birthdayIndex = index.model()->index(index.row(), 1);
         const QString name = nameIndex.data(Qt::DisplayRole).toString();
         QDate date = birthdayIndex.data(BirthdayModel::DateRole).toDate();
         date.setDate(thisYear, date.month(), date.day());
         if (date <= today)
             date.setDate(thisYear + 1, date.month(), date.day());
         KAEvent event(KADateTime(date, KADateTime::LocalZone),
+                      (mName ? mName->text() : QString()),
                       mPrefix->text() + name + mSuffix->text(),
                       mFontColourButton->bgColour(), mFontColourButton->fgColour(),
                       mFontColourButton->font(), KAEvent::MESSAGE, mLateCancel->minutes(),
                       mFlags, true);
         float fadeVolume;
         int   fadeSecs;
-        float volume = mSoundPicker->volume(fadeVolume, fadeSecs);
-        int   repeatPause = mSoundPicker->repeatPause();
+        const float volume = mSoundPicker->volume(fadeVolume, fadeSecs);
+        const int   repeatPause = mSoundPicker->repeatPause();
         event.setAudioFile(mSoundPicker->file().toDisplayString(), volume, fadeVolume, fadeSecs, repeatPause);
         const QVector<int> months(1, date.month());
         event.setRecurAnnualByDate(1, months, 0, KARecurrence::defaultFeb29Type(), -1, QDate());
@@ -357,8 +362,8 @@ void BirthdayDlg::resizeViewColumns()
 */
 void BirthdayDlg::slotTextLostFocus()
 {
-    QString prefix = mPrefix->text();
-    QString suffix = mSuffix->text();
+    const QString prefix = mPrefix->text();
+    const QString suffix = mSuffix->text();
     if (prefix != mPrefixText  ||  suffix != mSuffixText)
     {
         // Text has changed - re-evaluate the selection list
