@@ -1,21 +1,9 @@
 /*
  *  fontcolour.cpp  -  font and colour chooser widget
  *  Program:  kalarm
- *  Copyright © 2001-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "fontcolour.h"
@@ -37,7 +25,7 @@ FontColourChooser::FontColourChooser(QWidget* parent, const QStringList& fontLis
            const QString& frameLabel, bool fg, bool defaultFont, int visibleListSize)
     : QWidget(parent)
 {
-    QVBoxLayout* topLayout = new QVBoxLayout(this);
+    auto* topLayout = new QVBoxLayout(this);
     QWidget* page = this;
     if (!frameLabel.isNull())
     {
@@ -47,17 +35,17 @@ FontColourChooser::FontColourChooser(QWidget* parent, const QStringList& fontLis
     }
     else
         topLayout->setContentsMargins(0, 0, 0, 0);
-    QHBoxLayout* hlayout = new QHBoxLayout();
+    auto* hlayout = new QHBoxLayout();
     hlayout->setContentsMargins(0, 0, 0, 0);
     topLayout->addLayout(hlayout);
-    QVBoxLayout* colourLayout = new QVBoxLayout();
+    auto* colourLayout = new QVBoxLayout();
     colourLayout->setContentsMargins(0, 0, 0, 0);
     hlayout->addLayout(colourLayout);
     if (fg)
     {
         QWidget* box = new QWidget(page);    // to group widgets for QWhatsThis text
         colourLayout->addWidget(box);
-        QHBoxLayout* boxHLayout = new QHBoxLayout(box);
+        auto* boxHLayout = new QHBoxLayout(box);
         boxHLayout->setContentsMargins(0, 0, 0, 0);
 
         QLabel* label = new QLabel(i18nc("@label:listbox", "Foreground color:"), box);
@@ -72,7 +60,7 @@ FontColourChooser::FontColourChooser(QWidget* parent, const QStringList& fontLis
 
     QWidget* box = new QWidget(page);    // to group widgets for QWhatsThis text
     colourLayout->addWidget(box);
-    QHBoxLayout* boxHLayout = new QHBoxLayout(box);
+    auto* boxHLayout = new QHBoxLayout(box);
     boxHLayout->setContentsMargins(0, 0, 0, 0);
 
     QLabel* label = new QLabel(i18nc("@label:listbox", "Background color:"), box);
@@ -87,7 +75,7 @@ FontColourChooser::FontColourChooser(QWidget* parent, const QStringList& fontLis
 
     if (defaultFont)
     {
-        QHBoxLayout* layout = new QHBoxLayout();
+        auto* layout = new QHBoxLayout();
         layout->setContentsMargins(0, 0, 0, 0);
         topLayout->addLayout(layout);
         mDefaultFont = new CheckBox(i18nc("@option:check", "Use default font"), page);
