@@ -1,21 +1,9 @@
 /*
  *  synchtimer.cpp  -  timers which synchronize to time boundaries
  *  Program:  kalarm
- *  Copyright © 2004-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2004-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "synchtimer.h"
@@ -24,7 +12,6 @@
 
 #include <QTimer>
 #include <QDateTime>
-#include <QTime>
 
 /*=============================================================================
 =  Class: SynchTimer
@@ -79,7 +66,7 @@ void SynchTimer::disconnecT(QObject* receiver, const char* member)
         {
             for (int i = 0;  i < mConnections.count();  )
             {
-                if (mConnections[i].receiver == receiver)
+                if (mConnections.at(i).receiver == receiver)
                     mConnections.removeAt(i);
                 else
                     ++i;
@@ -127,11 +114,11 @@ void MinuteTimer::slotTimer()
 =  Application-wide timer synchronized to midnight.
 =============================================================================*/
 
-QList<DailyTimer*> DailyTimer::mFixedTimers;
+QVector<DailyTimer*> DailyTimer::mFixedTimers;
 
 DailyTimer::DailyTimer(const QTime& timeOfDay, bool fixed)
-    : mTime(timeOfDay),
-      mFixed(fixed)
+    : mTime(timeOfDay)
+    , mFixed(fixed)
 {
     if (fixed)
         mFixedTimers.append(this);
@@ -145,9 +132,9 @@ DailyTimer::~DailyTimer()
 
 DailyTimer* DailyTimer::fixedInstance(const QTime& timeOfDay, bool create)
 {
-    for (int i = 0, end = mFixedTimers.count();  i < end;  ++i)
-        if (mFixedTimers[i]->mTime == timeOfDay)
-            return mFixedTimers[i];
+    for (DailyTimer* timer : qAsConst(mFixedTimers))
+        if (timer->mTime == timeOfDay)
+            return timer;
     return create ? new DailyTimer(timeOfDay, true) : nullptr;
 }
 
