@@ -1,21 +1,9 @@
 /*
  *  timespinbox.h  -  time spinbox widget
  *  Program:  kalarm
- *  Copyright © 2001-2019 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2019 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef TIMESPINBOX_H
@@ -83,7 +71,7 @@ class TimeSpinBox : public SpinBox2
         /** Sets the maximum value which can be held in the spin box. */
         void            setMaximum(const QTime& t)   { SpinBox2::setMaximum(t.hour()*60 + t.minute()); }
         /** Returns the maximum value which can be held in the spin box. */
-        QTime           maxTime() const              { int mv = maximum();  return QTime(mv/60, mv%60); }
+        QTime           maxTime() const              { int mv = maximum();  return {mv/60, mv%60}; }
         /** Called whenever the user triggers a step, to adjust the value of the spin box.
          *  If the value was previously invalid, the spin box is set to the minimum value.
          */
