@@ -1,21 +1,9 @@
 /*
  *  akonadiresourcecreator.cpp  -  interactively create an Akonadi resource
  *  Program:  kalarm
- *  Copyright © 2011-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2011-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "akonadiresourcecreator.h"
@@ -82,7 +70,7 @@ void AkonadiResourceCreator::doCreateResource()
             connect(Resources::instance(), &Resources::resourceAdded,
                                      this, &AkonadiResourceCreator::slotResourceAdded);
 
-            AgentInstanceCreateJob* job = new AgentInstanceCreateJob(mAgentType, mParent);
+            auto* job = new AgentInstanceCreateJob(mAgentType, mParent);
             connect(job, &AgentInstanceCreateJob::result, this, &AkonadiResourceCreator::agentInstanceCreated);
             job->start();
             return;
@@ -97,7 +85,7 @@ void AkonadiResourceCreator::doCreateResource()
 */
 void AkonadiResourceCreator::agentInstanceCreated(KJob* j)
 {
-    AgentInstanceCreateJob* job = static_cast<AgentInstanceCreateJob*>(j);
+    auto* job = static_cast<AgentInstanceCreateJob*>(j);
     if (j->error())
     {
         qCCritical(KALARM_LOG) << "AkonadiResourceCreator::agentInstanceCreated: Failed to create new calendar resource:" << j->errorString();
