@@ -1,21 +1,9 @@
 /*
  *  eventmodel.cpp  -  model containing flat list of events
  *  Program:  kalarm
- *  Copyright © 2007-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2007-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "eventmodel.h"
@@ -58,7 +46,7 @@ KAEvent EventListModel::event(int row) const
 */
 KAEvent EventListModel::event(const QModelIndex& index) const
 {
-    KDescendantsProxyModel* proxyModel = static_cast<KDescendantsProxyModel*>(sourceModel());
+    auto* proxyModel = static_cast<KDescendantsProxyModel*>(sourceModel());
     const QModelIndex dataIndex = proxyModel->mapToSource(mapToSource(index));
     return (*mEventFunction)(dataIndex);
 }
@@ -68,7 +56,7 @@ KAEvent EventListModel::event(const QModelIndex& index) const
 */
 QModelIndex EventListModel::eventIndex(const QString& eventId) const
 {
-    KDescendantsProxyModel* proxyModel = static_cast<KDescendantsProxyModel*>(sourceModel());
+    auto* proxyModel = static_cast<KDescendantsProxyModel*>(sourceModel());
     return mapFromSource(proxyModel->mapFromSource(((*mEventIndexFunction)(eventId))));
 }
 
@@ -101,8 +89,8 @@ QModelIndexList EventListModel::match(const QModelIndex& start, int role, const
     if (role < Qt::UserRole)
         return QSortFilterProxyModel::match(start, role, value, hits, flags);
 
-    QModelIndexList matches;
-    const QModelIndexList indexes = sourceModel()->match(mapToSource(start), role, value, hits, flags);
+    QModelIndexList matches;           //clazy:exclude=inefficient-qlist
+    const QModelIndexList indexes = sourceModel()->match(mapToSource(start), role, value, hits, flags);      //clazy:exclude=inefficient-qlist
     for (const QModelIndex& ix : indexes)
     {
         QModelIndex proxyIndex = mapFromSource(ix);
@@ -130,7 +118,7 @@ QVariant EventListModel::headerData(int section, Qt::Orientation orientation, in
 bool EventListModel::filterAcceptsRow(int sourceRow, const QModelIndex& sourceParent) const
 {
     // Get the resource which contains this event.
-    KDescendantsProxyModel* proxyModel = static_cast<KDescendantsProxyModel*>(sourceModel());
+    auto* proxyModel = static_cast<KDescendantsProxyModel*>(sourceModel());
     const QModelIndex dataIndex = proxyModel->mapToSource(proxyModel->index(sourceRow, 0, sourceParent));
     const QString eventId = dataIndex.data(ResourceDataModelBase::EventIdRole).toString();
     if (eventId.isEmpty())
@@ -276,6 +264,33 @@ bool AlarmListModel::filterAcceptsColumn(int sourceCol, const QModelIndex& ix) c
     return (sourceCol != ResourceDataModelBase::TemplateNameColumn);
 }
 
+/******************************************************************************
+* Return the data for a given index from the model.
+*/
+QVariant AlarmListModel::data(const QModelIndex& ix, int role) const
+{
+    if (mReplaceBlankName  &&  ix.column() == NameColumn)
+    {
+        // It's the Name column, and the name is being replaced by the alarm text
+        // when the name is blank. Return the alarm text instead for display and
+        // tooltip.
+        switch (role)
+        {
+            case Qt::DisplayRole:
+            case Qt::ToolTipRole:
+                if (EventListModel::data(ix, role).toString().isEmpty())
+                {
+                    const QModelIndex& ix2 = ix.siblingAtColumn(TextColumn);
+                    return EventListModel::data(ix2, role);
+                }
+                break;
+            default:
+                break;
+        }
+    }
+    return EventListModel::data(ix, role);
+}
+
 QVariant AlarmListModel::headerData(int section, Qt::Orientation orientation, int role) const
 {
     if (orientation == Qt::Horizontal)
