@@ -1,21 +1,9 @@
 /*
  *  eventmodel.h  -  model containing flat list of events
  *  Program:  kalarm
- *  Copyright © 2010-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2010-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef EVENTMODEL_H
@@ -121,7 +109,7 @@ class AlarmListModel : public EventListModel
 public:
     enum   // data columns
     {
-        TimeColumn = 0, TimeToColumn, RepeatColumn, ColourColumn, TypeColumn, TextColumn,
+        TimeColumn = 0, TimeToColumn, RepeatColumn, ColourColumn, TypeColumn, NameColumn, TextColumn,
         ColumnCount
     };
 
@@ -145,6 +133,9 @@ public:
      */
     CalEvent::Types eventTypeFilter() const   { return mFilterTypes; }
 
+    /** Set whether to replace a blank alarm name with the alarm text. */
+    void setReplaceBlankName(bool replace)   { mReplaceBlankName = replace; }
+
     int  columnCount(const QModelIndex& = QModelIndex()) const  override { return ColumnCount; }
     QVariant headerData(int section, Qt::Orientation, int role = Qt::DisplayRole) const override;
 
@@ -153,10 +144,12 @@ protected:
 
     bool filterAcceptsRow(int sourceRow, const QModelIndex& sourceParent) const override;
     bool filterAcceptsColumn(int sourceCol, const QModelIndex& sourceParent) const override;
+    QVariant data(const QModelIndex&, int role) const override;
 
 private:
     static AlarmListModel* mAllInstance;
-    CalEvent::Types mFilterTypes;  // types of events contained in this model
+    CalEvent::Types mFilterTypes;    // types of events contained in this model
+    bool mReplaceBlankName {false};  // replace Name with Text for Qt::DisplayRole if Name is blank
 };
 
 
@@ -220,7 +213,7 @@ private:
 template <class DataModel>
 EventListModel* EventListModel::create(CalEvent::Types types, QObject* parent)
 {
-    EventListModel* model = new EventListModel(types, parent);
+    auto* model = new EventListModel(types, parent);
     model->initialise<DataModel>();
     return model;
 }
@@ -236,7 +229,7 @@ template <class DataModel> void EventListModel::initialise()
 template <class DataModel>
 AlarmListModel* AlarmListModel::create(QObject* parent)
 {
-    AlarmListModel* model = new AlarmListModel(parent);
+    auto* model = new AlarmListModel(parent);
     model->EventListModel::initialise<DataModel>();
     return model;
 }
@@ -255,7 +248,7 @@ AlarmListModel* AlarmListModel::all()
 template <class DataModel>
 TemplateListModel* TemplateListModel::create(QObject* parent)
 {
-    TemplateListModel* model = new TemplateListModel(parent);
+    auto* model = new TemplateListModel(parent);
     model->EventListModel::initialise<DataModel>();
     return model;
 }
