@@ -1,21 +1,9 @@
 /*
  *  resourcetype.cpp  -  base class for an alarm calendar resource type
  *  Program:  kalarm
- *  Copyright © 2019-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2019-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "resourcetype.h"
@@ -198,7 +186,6 @@ void ResourceType::setLoadedEvents(QHash<QString, KAEvent>& newEvents)
     // longer exist.
     QStringList    eventsToDelete;
     QList<KAEvent> eventsToNotifyDelete;
-    QVector<decltype(mEvents)::iterator> iteratorsToDelete;
     for (auto it = mEvents.begin();  it != mEvents.end();  ++it)
     {
         const QString& id = it.key();
@@ -311,8 +298,7 @@ void ResourceType::setDeletedEvents(const QList<KAEvent>& events)
     QList<KAEvent> eventsToNotify;
     for (const KAEvent& event : events)
     {
-        QHash<QString, KAEvent>::iterator it = mEvents.find(event.id());
-        if (it != mEvents.end())
+        if (mEvents.constFind(event.id()) != mEvents.constEnd())
         {
             eventsToDelete += event.id();
             if (event.category() & types)
@@ -321,7 +307,7 @@ void ResourceType::setDeletedEvents(const QList<KAEvent>& events)
     }
     if (!eventsToNotify.isEmpty())
         Resources::notifyEventsToBeRemoved(this, eventsToNotify);
-    for (const QString& id : eventsToDelete)
+    for (const QString& id : qAsConst(eventsToDelete))
         mEvents.remove(id);
     if (!eventsToNotify.isEmpty())
         Resources::notifyEventsRemoved(this, eventsToNotify);
