@@ -1,21 +1,9 @@
 /*
  *  traywindow.cpp  -  the KDE system tray applet
  *  Program:  kalarm
- *  Copyright © 2002-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2002-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "traywindow.h"
@@ -23,7 +11,7 @@
 #include "functions.h"
 #include "kalarmapp.h"
 #include "mainwindow.h"
-#include "messagewin.h"
+#include "messagedisplay.h"
 #include "newalarmaction.h"
 #include "prefdlg.h"
 #include "preferences.h"
@@ -96,14 +84,14 @@ TrayWindow::TrayWindow(MainWindow* parent)
     addAction(QStringLiteral("tSpread"), a);
     contextMenu()->addAction(a);
     contextMenu()->addSeparator();
-    contextMenu()->addAction(KStandardAction::preferences(this, SLOT(slotPreferences()), this));
+    contextMenu()->addAction(KStandardAction::preferences(this, &TrayWindow::slotPreferences, this));
 
-    // Disable standard quit behaviour. We have to intercept the quit even,
-    // if the main window is hidden.
+    // Disable standard quit behaviour. We have to intercept the quit event
+    // (which triggers KStatusNotifierItem to quit unconditionally).
     QAction* act = action(QStringLiteral("quit"));
     if (act)
     {
-        act->disconnect(SIGNAL(triggered(bool)), this, SLOT(maybeQuit()));
+        disconnect(act, &QAction::triggered, this, nullptr);
         connect(act, &QAction::triggered, this, &TrayWindow::slotQuit);
     }
 
@@ -129,26 +117,21 @@ TrayWindow::TrayWindow(MainWindow* parent)
 
     // Update when alarms are modified
     AlarmListModel* all = DataModel::allAlarmListModel();
-    connect(all, SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-            mToolTipUpdateTimer, SLOT(start()));
-    connect(all, SIGNAL(rowsInserted(QModelIndex,int,int)),
-            mToolTipUpdateTimer, SLOT(start()));
-    connect(all, SIGNAL(rowsMoved(QModelIndex,int,int,QModelIndex,int)),
-            mToolTipUpdateTimer, SLOT(start()));
-    connect(all, SIGNAL(rowsRemoved(QModelIndex,int,int)),
-            mToolTipUpdateTimer, SLOT(start()));
-    connect(all, SIGNAL(modelReset()),
-            mToolTipUpdateTimer, SLOT(start()));
+    connect(all, &QAbstractItemModel::dataChanged,  mToolTipUpdateTimer, QOverload<>::of(&QTimer::start));
+    connect(all, &QAbstractItemModel::rowsInserted, mToolTipUpdateTimer, QOverload<>::of(&QTimer::start));
+    connect(all, &QAbstractItemModel::rowsMoved,    mToolTipUpdateTimer, QOverload<>::of(&QTimer::start));
+    connect(all, &QAbstractItemModel::rowsRemoved,  mToolTipUpdateTimer, QOverload<>::of(&QTimer::start));
+    connect(all, &QAbstractItemModel::modelReset,   mToolTipUpdateTimer, QOverload<>::of(&QTimer::start));
 
     // Set auto-hide status when next alarm or preferences change
     mStatusUpdateTimer->setSingleShot(true);
     connect(mStatusUpdateTimer, &QTimer::timeout, this, &TrayWindow::updateStatus);
     connect(ResourcesCalendar::instance(), &ResourcesCalendar::earliestAlarmChanged, this, &TrayWindow::updateStatus);
-    Preferences::connect(SIGNAL(autoHideSystemTrayChanged(int)), this, SLOT(updateStatus()));
+    Preferences::connect(&Preferences::autoHideSystemTrayChanged, this, &TrayWindow::updateStatus);
     updateStatus();
 
     // Update when tooltip preferences are modified
-    Preferences::connect(SIGNAL(tooltipPreferencesChanged()), mToolTipUpdateTimer, SLOT(start()));
+    Preferences::connect(&Preferences::tooltipPreferencesChanged, mToolTipUpdateTimer, QOverload<>::of(&QTimer::start));
 }
 
 TrayWindow::~TrayWindow()
@@ -271,18 +254,18 @@ void TrayWindow::updateStatus()
     int period =  Preferences::autoHideSystemTray();
     // If the icon is always to be shown (AutoHideSystemTray = 0),
     // or audio is playing, show the icon.
-    bool active = !period || MessageWin::isAudioPlaying();
+    bool active = !period || MessageDisplay::isAudioPlaying();
     if (!active)
     {
         // Show the icon only if the next active alarm complies
         active = theApp()->alarmsEnabled();
         if (active)
         {
-            const KAEvent& event = ResourcesCalendar::earliestAlarm();
+            KADateTime dt;
+            const KAEvent& event = ResourcesCalendar::earliestAlarm(dt);
             active = event.isValid();
             if (active  &&  period > 0)
             {
-                const KADateTime dt = event.nextTrigger(KAEvent::ALL_TRIGGER).effectiveKDateTime();
                 qint64 delay = KADateTime::currentLocalDateTime().secsTo(dt);
                 delay -= static_cast<qint64>(period) * 60;   // delay until icon to be shown
                 active = (delay <= 0);
@@ -389,7 +372,7 @@ QString TrayWindow::tooltipAlarmText() const
             int it = 0;
             for (int itend = items.count();  it < itend;  ++it)
             {
-                if (item.dateTime <= items[it].dateTime)
+                if (item.dateTime <= items.at(it).dateTime)
                     break;
             }
             items.insert(it, item);
@@ -400,10 +383,10 @@ QString TrayWindow::tooltipAlarmText() const
     int count = 0;
     for (i = 0, iend = items.count();  i < iend;  ++i)
     {
-        qCDebug(KALARM_LOG) << "TrayWindow::tooltipAlarmText: --" << (count+1) << ")" << items[i].text;
+        qCDebug(KALARM_LOG) << "TrayWindow::tooltipAlarmText: --" << (count+1) << ")" << items.at(i).text;
         if (i > 0)
             text += QLatin1String("<br />");
-        text += items[i].text;
+        text += items.at(i).text;
         if (++count == maxCount)
             break;
     }
